
__version__ = '0.0.8'

__title__ = 'prespy'

__summary__ = 'Package for working with the Neurobehavioural Systems Presentation logfiles within python'

__uri__ = 'https://github.com/gjcooper/prespy'

__license__ = 'GPLv2'

__author__ = 'Gavin Cooper'

__email__ = 'gjcooper@gmail.com'
